==> xcsoar-7.19.tar.xz: xcsoar-7.19/src/Device/Port/AndroidPort.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_DEVICE_ANDROID_PORT_HPP
#define XCSOAR_DEVICE_ANDROID_PORT_HPP

#include "BufferedPort.hpp"

class PortBridge;

/**
 * A #Port implementation which transmits data over a Bluetooth RFCOMM
 * socket.
 */
class AndroidPort : public BufferedPort
{
  PortBridge *bridge;

public:
  AndroidPort(PortListener *_listener, DataHandler &_handler,
              PortBridge *bridge);
  ~AndroidPort() override;

  /* virtual methods from class Port */
  PortState GetState() const override;
  bool Drain() override;
  unsigned GetBaudrate() const override;
  bool SetBaudrate(unsigned baud_rate) override;
  size_t Write(const void *data, size_t length) override;
};

#endif

==> xcsoar-7.22.tar.xz: xcsoar-7.22/src/Device/Port/AndroidPort.hpp <==
/*
Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef XCSOAR_DEVICE_ANDROID_PORT_HPP
#define XCSOAR_DEVICE_ANDROID_PORT_HPP

#include "BufferedPort.hpp"

class PortBridge;

/**
 * A #Port implementation which transmits data over a Bluetooth RFCOMM
 * socket.
 */
class AndroidPort : public BufferedPort
{
  PortBridge *bridge;

public:
  AndroidPort(PortListener *_listener, DataHandler &_handler,
              PortBridge *bridge);
  ~AndroidPort() noexcept override;

  /* virtual methods from class Port */
  PortState GetState() const noexcept override;
  bool Drain() override;
  unsigned GetBaudrate() const noexcept override;
  void SetBaudrate(unsigned baud_rate) override;
  std::size_t Write(const void *data, std::size_t length) override;
};

#endif
